==> jc-1.4.0.tar.gz: javax/rmi/CORBA/ObjectImpl.h <==
// public class javax.rmi.CORBA.ObjectImpl

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5219dfd5835e78ba javax_rmi_CORBA_ObjectImpl

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_rmi_CORBA_ObjectImpl_H_
#define _JC_javax_rmi_CORBA_ObjectImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_rmi_CORBA_ObjectImpl$object;

// Typedefs
typedef struct _jc_javax_rmi_CORBA_ObjectImpl$sub_refs	_jc_javax_rmi_CORBA_ObjectImpl$sub_refs;
typedef struct _jc_javax_rmi_CORBA_ObjectImpl$sub_nonrefs	_jc_javax_rmi_CORBA_ObjectImpl$sub_nonrefs;
typedef struct _jc_javax_rmi_CORBA_ObjectImpl$refs	_jc_javax_rmi_CORBA_ObjectImpl$refs;
typedef struct _jc_javax_rmi_CORBA_ObjectImpl$nonrefs	_jc_javax_rmi_CORBA_ObjectImpl$nonrefs;
typedef struct _jc_javax_rmi_CORBA_ObjectImpl$object	_jc_javax_rmi_CORBA_ObjectImpl$object;

typedef const struct _jc_javax_rmi_CORBA_ObjectImpl$vmethods	_jc_javax_rmi_CORBA_ObjectImpl$vmethods;
typedef const struct _jc_javax_rmi_CORBA_ObjectImpl$vtable	_jc_javax_rmi_CORBA_ObjectImpl$vtable;
typedef const struct _jc_javax_rmi_CORBA_ObjectImpl$vtype	_jc_javax_rmi_CORBA_ObjectImpl$vtype;

// Constructors
extern void _jc_javax_rmi_CORBA_ObjectImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *);

// Virtual methods
extern struct _jc_javax_rmi_CORBA_ObjectImpl$object *_jc_javax_rmi_CORBA_ObjectImpl$method$__5forb$f24a92ad29cb213f(_jc_env *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *);
extern struct _jc_java_lang_String$object *_jc_javax_rmi_CORBA_ObjectImpl$method$object__5fto__5fstring$5dd32cbc824920ca(_jc_env *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_rmi_CORBA_ObjectImpl$method_info$__5forb$f24a92ad29cb213f;
extern _jc_method _jc_javax_rmi_CORBA_ObjectImpl$method_info$object__5fto__5fstring$5dd32cbc824920ca;

// Virtual methods structure
struct _jc_javax_rmi_CORBA_ObjectImpl$vmethods {
	struct _jc_javax_rmi_CORBA_ObjectImpl$object	*(*__5forb$f24a92ad29cb213f)(_jc_env *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *);
	struct _jc_java_lang_String$object	*(*object__5fto__5fstring$5dd32cbc824920ca)(_jc_env *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *);
};

// Vtable
struct _jc_javax_rmi_CORBA_ObjectImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_rmi_CORBA_ObjectImpl$vmethods	javax_rmi_CORBA_ObjectImpl;
};

// Vtype
struct _jc_javax_rmi_CORBA_ObjectImpl$vtype {
	_jc_type			type;
	_jc_javax_rmi_CORBA_ObjectImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_ObjectImpl$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_rmi_CORBA_ObjectImpl$refs {
    _jc_javax_rmi_CORBA_ObjectImpl$sub_refs	javax_rmi_CORBA_ObjectImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_ObjectImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_rmi_CORBA_ObjectImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_rmi_CORBA_ObjectImpl$sub_nonrefs	javax_rmi_CORBA_ObjectImpl;
};

// Object instance structure
struct _jc_javax_rmi_CORBA_ObjectImpl$object {
	_jc_javax_rmi_CORBA_ObjectImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_rmi_CORBA_ObjectImpl$vtype	*vtype;
	_jc_javax_rmi_CORBA_ObjectImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_rmi_CORBA_ObjectImpl$vtype _jc_javax_rmi_CORBA_ObjectImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_rmi_CORBA_ObjectImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_rmi_CORBA_ObjectImpl$class_object;

#endif	/* _JC_javax_rmi_CORBA_ObjectImpl_H_ */

==> jc-1.4.6.tar.gz: javax/rmi/CORBA/ObjectImpl.h <==
// public class javax.rmi.CORBA.ObjectImpl

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5219dfd5835e78ba javax_rmi_CORBA_ObjectImpl

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_rmi_CORBA_ObjectImpl_H_
#define _JC_javax_rmi_CORBA_ObjectImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_rmi_CORBA_ObjectImpl$object;

// Typedefs
typedef struct _jc_javax_rmi_CORBA_ObjectImpl$sub_refs	_jc_javax_rmi_CORBA_ObjectImpl$sub_refs;
typedef struct _jc_javax_rmi_CORBA_ObjectImpl$sub_nonrefs	_jc_javax_rmi_CORBA_ObjectImpl$sub_nonrefs;
typedef struct _jc_javax_rmi_CORBA_ObjectImpl$refs	_jc_javax_rmi_CORBA_ObjectImpl$refs;
typedef struct _jc_javax_rmi_CORBA_ObjectImpl$nonrefs	_jc_javax_rmi_CORBA_ObjectImpl$nonrefs;
typedef struct _jc_javax_rmi_CORBA_ObjectImpl$object	_jc_javax_rmi_CORBA_ObjectImpl$object;

typedef const struct _jc_javax_rmi_CORBA_ObjectImpl$vmethods	_jc_javax_rmi_CORBA_ObjectImpl$vmethods;
typedef const struct _jc_javax_rmi_CORBA_ObjectImpl$vtable	_jc_javax_rmi_CORBA_ObjectImpl$vtable;
typedef const struct _jc_javax_rmi_CORBA_ObjectImpl$vtype	_jc_javax_rmi_CORBA_ObjectImpl$vtype;

// Constructors
extern void _jc_javax_rmi_CORBA_ObjectImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_rmi_CORBA_ObjectImpl$object *_jc_javax_rmi_CORBA_ObjectImpl$method$__5forb$f24a92ad29cb213f(_jc_env *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_rmi_CORBA_ObjectImpl$method$object__5fto__5fstring$5dd32cbc824920ca(_jc_env *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_rmi_CORBA_ObjectImpl$method_info$__5forb$f24a92ad29cb213f;
extern _jc_method _jc_javax_rmi_CORBA_ObjectImpl$method_info$object__5fto__5fstring$5dd32cbc824920ca;

// Virtual methods structure
struct _jc_javax_rmi_CORBA_ObjectImpl$vmethods {
	struct _jc_javax_rmi_CORBA_ObjectImpl$object	*(*__5forb$f24a92ad29cb213f)(_jc_env *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*object__5fto__5fstring$5dd32cbc824920ca)(_jc_env *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *, struct _jc_javax_rmi_CORBA_ObjectImpl$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_rmi_CORBA_ObjectImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_rmi_CORBA_ObjectImpl$vmethods	javax_rmi_CORBA_ObjectImpl;
};

// Vtype
struct _jc_javax_rmi_CORBA_ObjectImpl$vtype {
	_jc_type			type;
	_jc_javax_rmi_CORBA_ObjectImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_ObjectImpl$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_rmi_CORBA_ObjectImpl$refs {
    _jc_javax_rmi_CORBA_ObjectImpl$sub_refs	javax_rmi_CORBA_ObjectImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_ObjectImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_rmi_CORBA_ObjectImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_rmi_CORBA_ObjectImpl$sub_nonrefs	javax_rmi_CORBA_ObjectImpl;
};

// Object instance structure
struct _jc_javax_rmi_CORBA_ObjectImpl$object {
	_jc_javax_rmi_CORBA_ObjectImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_rmi_CORBA_ObjectImpl$vtype	*vtype;
	_jc_javax_rmi_CORBA_ObjectImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_rmi_CORBA_ObjectImpl$vtype _jc_javax_rmi_CORBA_ObjectImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_rmi_CORBA_ObjectImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_rmi_CORBA_ObjectImpl$class_object;

#endif	/* _JC_javax_rmi_CORBA_ObjectImpl_H_ */
